@@ -253,6 +253,9 @@ class Note(object):
         """
         return NOTES.index(self.name) + (12 * self.octave)
 
+    def invert(self, *args):
+        return self.copy()
+
     def __repr__(self):
         return "Note<%s|%s,len=%s,time=%s/%s,cc=%s,tie=%s,muted=%s,track_copy=%s>" % (
             self.name,
