@@ -12,54 +12,9 @@ from .scale import Scale
 from .transform import Transform
 import warpseq.utils.utils as utils
 from warpseq.api.exceptions import *
+from warpseq.model.directions import *
 
-FORWARD='forward'
-REVERSE='reverse'
-OSCILLATE='oscillate'
-PENDULUM='pendulum'
-RANDOM='random'
-SERIALIZED='serialized'
-BROWNIAN1='brownian1'
-BROWNIAN2='brownian2'
-BROWNIAN3='brownian3'
-BROWNIAN4='brownian4'
-BROWNIAN5='brownian5'
-BROWNIAN6='brownian6'
-BUILD='build'
-
-DIRECTIONS = [
-    FORWARD,
-    REVERSE,
-    OSCILLATE,
-    PENDULUM,
-    RANDOM,
-    SERIALIZED,
-    BROWNIAN1,
-    BROWNIAN2,
-    BROWNIAN3,
-    BROWNIAN4,
-    BROWNIAN5,
-    BROWNIAN6,
-    BUILD
-]
-
-DIRECTION_MAP = {
-    FORWARD:    utils.roller,
-    REVERSE:    utils.reverse_roller,
-    OSCILLATE:  utils.oscillate_roller,
-    PENDULUM:   utils.pendulum_roller,
-    SERIALIZED: utils.serialized_roller,
-    RANDOM:     utils.random_roller,
-    BROWNIAN1:  utils.brownian1_roller,
-    BROWNIAN2:  utils.brownian2_roller,
-    BROWNIAN3:  utils.brownian3_roller,
-    BROWNIAN4:  utils.brownian4_roller,
-    BROWNIAN5:  utils.brownian5_roller,
-    BROWNIAN6:  utils.brownian6_roller,
-    BUILD:      utils.build_roller
-}
-
-class Pattern(NewReferenceObject):
+class Pattern(NewReferenceObject, Directionable):
 
     __slots__ = [ 'name', 'slots', 'current_slots', 'octave_shift', 'rate', 'scale', 'direction', 'current_direction', 'length', '_iterator', 'obj_id' ]
 
@@ -86,23 +41,9 @@ class Pattern(NewReferenceObject):
         super(Pattern, self).__init__()
         self.reset()
 
-    def reset(self):
-        self.current_slots = self.slots[:]
-        self.apply_direction()
-
     def get_octave_shift(self, track):
         return track.instrument.base_octave + self.octave_shift
 
-    def apply_direction(self):
-        fn = DIRECTION_MAP.get(self.direction, None)
-        if fn is not None:
-            self._iterator = fn(self.current_slots)
-        else:
-            raise Exception("internal error: direction (%s) not implemented" % self.direction)
-
-    def get_next(self):
-        return next(self._iterator)
-
     def get_length(self):
         return self.length
 
