@@ -108,6 +108,12 @@ class Song(NewReferenceObject):
                 return v
         return None
 
+    def find_track_by_name(self, name):
+        for v in self.tracks:
+            if v.name == name:
+                return v
+        return None
+
     def find_transform(self, obj_id):
         """
         Returns the transform with the given object ID.
