@@ -10,6 +10,7 @@
 from ..notation.mod import ModExpression
 from ..utils.utils import roller
 from .base import NewReferenceObject
+from .directions import *
 
 
 CHORDS = 'chords'
@@ -17,30 +18,34 @@ NOTES = 'notes'
 BOTH = 'both'
 APPLIES_CHOICES = [ CHORDS, NOTES, BOTH ]
 
-class Transform(NewReferenceObject):
+class Transform(NewReferenceObject, Directionable):
 
-    __slots__ = [ 'name', 'slots', 'octave_slots', 'divide', 'applies_to', 'obj_id', '_mod', '_slot_mods', '_repeat_processor' ]
+    __slots__ = [ 'name', 'slots', 'current_slots', 'octave_slots', 'divide', 'applies_to', 'obj_id',
+                  'direction', 'current_direction', '_iterator', '_mod', '_slot_mods', '_repeat_processor' ]
 
-    def __init__(self, name=None, slots=None, octave_slots=None, divide=1, obj_id=None, applies_to=None, _repeat_processor=False):
+    def __init__(self, name=None, slots=None, octave_slots=None, divide=1, obj_id=None,
+                 applies_to=None, _repeat_processor=False, direction=FORWARD):
         self.name = name
         self.slots = slots
-        self.octave_slots = octave_slots
         self.divide = divide
+        self.octave_slots = octave_slots # FIXME: these could be removed
         self.applies_to = applies_to
         self.obj_id = obj_id
         self._repeat_processor = _repeat_processor
         self._mod = ModExpression(defer=False)
         self._slot_mods = roller(slots)
+        self.direction = direction
+        self.current_direction = direction
 
         if applies_to is None:
             applies_to = BOTH
         self.applies_to = applies_to
 
         assert applies_to in APPLIES_CHOICES
+        self.reset()
 
         super(Transform, self).__init__()
 
-
     def to_dict(self):
         return dict(
             obj_id = self.obj_id,
@@ -48,7 +53,8 @@ class Transform(NewReferenceObject):
             slots = self.slots,
             octave_slots = self.octave_slots,
             applies_to = self.applies_to,
-            divide = self.divide
+            divide = self.divide,
+            direction = self.direction
         )
 
     @classmethod
@@ -59,7 +65,8 @@ class Transform(NewReferenceObject):
             slots = data['slots'],
             octave_slots = data['slots'],
             applies_to = data.get('applies_to', None),
-            divide = data.get('divide', None)
+            divide = data.get('divide', None),
+            direction = data.get('direction',FORWARD)
         )
 
     def process(self, song, scale, track, note_list, t_start, slot_duration):
@@ -74,6 +81,8 @@ class Transform(NewReferenceObject):
 
         self._mod.scale = scale
         self._mod.track = track
+
+        assert song is not None
         self._mod.song = song
 
         # notes is like: [n1, n2, n3], [n4], [], [n5, n6]
@@ -98,6 +107,8 @@ class Transform(NewReferenceObject):
 
         start_time = t_start
 
+        self.reset()
+
         for (i, notes2) in enumerate(note_list):
 
             (actual_notes, is_chord) = _expand_notes(notes2)
@@ -165,9 +176,10 @@ class Transform(NewReferenceObject):
                     else:
                         which_note = notes
 
-                    # apply the new time information
+                    # get the next transform slot from the iterator
 
-                    which_slot = next(self._slot_mods)
+                    which_slot = self.get_next()
+                    #print("WHICH SLOT=%s/%s/%s" % (i,j,which_slot))
 
                     # calculate the new note using the mod expression
 
