@@ -42,6 +42,9 @@ class Player(object):
         self.callbacks = Callbacks()
         self.start()
 
+    def get_multiplayer(self):
+        return self._multiplayer
+
     def wait_time(self):
         return min([ x.time for x in self.left_to_play ]) - self.time_index
 
@@ -61,7 +64,6 @@ class Player(object):
         note = event.note
         self.left_to_play.append(Event(
             type = NOTE_OFF,
-            off_event = None,
             on_event = event,
             time = event.time + note.length - NOTE_GAP,
             note = note.copy()
@@ -86,7 +88,7 @@ class Player(object):
         """
 
         self.time_index += milliseconds
-        ti = self.time_index
+
         ltp = self.left_to_play
 
         # consume any events we need to off the time queue
@@ -100,10 +102,8 @@ class Player(object):
                     self.engine.play(x)
                 self.left_to_play = [ x for x in ltp if x not in due ]
 
-
         if self.time_index >= self.clip_length_in_ms:
 
-
             # the play-head has advanced beyond the end of the clip
 
             if self._still_on_this_clip():
