@@ -89,8 +89,9 @@ class RealtimeEngine(object):
 
             exprs = event.note.flags['deferred_expressions']
             for expr in exprs:
+                #print("track %s has deferrals" % self.track.name)
 
-                assert event.note.from_scale is not None
+                #assert event.note.from_scale is not None
 
                 value = self.mod_expressions.do(event.note, expr)
                 if value is None:
@@ -133,14 +134,15 @@ class RealtimeEngine(object):
                 control = int(control)
                 #command = (MIDI_CONTROLLER_CHANGE & 0xf0) | (self.channel - 1 & 0xf)
                 #self.midi_out.send_message([command, channel & 0x7f, value & 0x7f])
+
                 msg = mido.Message(MIDO_CONTROLLER_CHANGE, channel=self.channel-1, control=control, value=value)
                 self.midi_out.send(msg)
 
 
             if not (self.track.muted or self.instrument.muted or event.note.muted):
 
+                #print("%s ON: %s" % (self.track.name, event.note))
                 self.on_ct = self.on_ct + 1
-                #print("ON (%s/%s)" % (self.track.name, event.note))
                 self.player.inject_off_event(event)
                 msg = mido.Message(MIDO_NOTE_ON, note=note_number, velocity=velocity, channel=self.channel-1)
                 self.midi_out.send(msg)
